# eric7.Preferences.ConfigurationPages.HelpViewersPage

Module implementing the Help Viewers configuration page.

### Global Attributes

None

### Classes

HelpViewersPage | Class implementing the Help Viewers configuration page.

### Functions

create | Module function to create the configuration page.

## HelpViewersPage

Class implementing the Help Viewers configuration page.

### Derived from

ConfigurationPageBase, Ui_HelpViewersPage

### Class Attributes

None

### Class Methods

None

### Methods

HelpViewersPage | Constructor
save | Public slot to save the Help Viewers configuration.

### Static Methods

None

#### HelpViewersPage (Constructor)

HelpViewersPage()

Constructor

#### HelpViewersPage.save

save()

Public slot to save the Help Viewers configuration.

Up

## create

create(dlg)

Module function to create the configuration page.

dlg
  reference to the configuration dialog

Return:
  reference to the instantiated page (ConfigurationPageBase)

Up